mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
* fix naming in swsusp
@ 2004-12-13 20:15 Pavel Machek
  0 siblings, 0 replies; only message in thread
From: Pavel Machek @ 2004-12-13 20:15 UTC (permalink / raw)
  To: Andrew Morton, kernel list

Hi!

At few points we still reference to swsusp as "pmdisk"... it might
confuse someone not knowing full history. Please apply,
								Pavel

--- clean/kernel/power/swsusp.c	2004-10-19 14:16:29.000000000 +0200
+++ linux/kernel/power/swsusp.c	2004-12-12 21:14:03.000000000 +0100
@@ -1202,7 +1190,7 @@
 }
 
 /**
  *	pmdisk_read - Read saved image from swap.
  */
 
 int __init swsusp_read(void)
@@ -1226,6 +1214,6 @@
 	if (!error)
 		pr_debug("Reading resume file was successful\n");
 	else
-		pr_debug("pmdisk: Error %d resuming\n", error);
+		pr_debug("swsusp: Error %d resuming\n", error);
 	return error;
 }
@@ -1202,7 +1190,7 @@
 
 /**
- *	pmdisk_read - Read saved image from swap.
+ *	swsusp_read - Read saved image from swap.
  */
 

-- 
People were complaining that M$ turns users into beta-testers...
...jr ghea gurz vagb qrirybcref, naq gurl frrz gb yvxr vg gung jnl!

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2004-12-13 20:23 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2004-12-13 20:15 fix naming in swsusp Pavel Machek

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

Powered by JetHome